@@ -11,7 +11,7 @@
 base64url_binary() ->
 	?LET(Binary,
 		binary(),
-		base64url:encode(Binary)).
+		jose_jwa_base64url:encode(Binary)).
 
 binary_map() ->
 	?LET(List,
@@ -63,7 +63,7 @@ jwk_hmac() ->
 		binary(),
 		jose_jwk:from_map(#{
 			<<"kty">> => <<"oct">>,
-			<<"k">> => base64url:encode(Key)
+			<<"k">> => jose_jwa_base64url:encode(Key)
 		})).
 
 jwk_rsa() ->
